==> dvdisaster_0.71.26.orig.tar.gz: dvdisaster-0.71.26/documentation/include/toc.php <==

<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2008 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

section("news");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

# Overview

section("index");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  de("Das große Bild");
  en("The big picture");
  ru("The big picture");

subsubsection("howtos61");
  de("richtige Anwendung");
  en("correct usage");
  ru("correct usage");

subsubsection("howtos62");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("incorrect usage");

subsection("howtos10");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителе");

subsubsection("howtos11");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Basic settings");

subsubsection("howtos12");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("foo");

subsubsection("howtos13");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("foo");

subsubsection("howtos14");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos20");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Создание данных для исправления ошибок");

subsubsection("howtos21");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Decision help");

subsubsection("howtos22");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Basic settings for reading");

subsubsection("howtos23");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Creating the error correction file");

subsubsection("howtos24");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Archiving error correction files");

subsubsection("howtos25");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos30");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Putting error correction data on the medium");

subsubsection("howtos31");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Decision help");

subsection("howtos40");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsection("howtos50");
  de("Informationen über Abbild und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsection("howtos90");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");

subsubsection("howtos91");
  de("Erzeugen eines Referenz-Abbildes");
  en("Creating the reference image");

subsubsection("howtos92");
  de("Erzeugen der zugehörigen Fehlerkorrektur-Daten");
  en("Creating the error correction file");

subsubsection("howtos93");
  de("Referenz-Abbild auf einen Datenträger schreiben");
  en("Writing the image to the medium.");

subsection("howtosa0");
  de("Bedienelemente");
  en("Dialogs and buttons");

subsubsection("howtosa1");
  de("Laufwerk auswählen");
  en("drive selection");

subsubsection("howtosa2");
  de("Abbild-Datei auswählen");
  en("Image file selection");

subsubsection("howtosa3");
  de("Fehlerkorrektur-Datei auswählen");
  en("Protection file selection");

subsubsection("howtosa4");
  de("Aktionen beginnen");
  en("Starting actions");
# Download

section("download");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download20");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  de("Installation");
  en("Installation");
  ru("Установка");

subsection("download40");
  de("Alpha-/Entwicklerversionen");
  en("Alpha (unstable) versions");
  ru("Альфа (нестабильные) версии");

# Questions and Answers

section("qa");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

# Feedback

section("feedback");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

# Imprint

section("imprint");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

# Privacy notice

section("privacy");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Privacy policy");
?>

==> dvdisaster_0.72~rc1.orig.tar.gz: dvdisaster-0.72.rc1/documentation/include/toc.php <==

<?php
# dvdisaster: Online doc table of contents (all languages)
# Copyright (C) 2007-2009 The dvdisaster translation team
#
# UTF-8 trigger: äöüß 

# News

section("news");
  de("Neuigkeiten");
  en("News");
  ru("Новости");

subsection("news2008");
  de("2008");
  en("2008");
  ru("2008");

subsection("news2007");
  de("2007");
  en("2007");
  ru("2007");

# Overview

section("index");
  de("Überblick");
  en("Overview");
  ru("Обзор");

subsection("index10");
  de("Beispiele für die Fehlerkorrektur");   
  en("Examples of the error correction");
  ru("Примеры исправления ошибок");

subsection("index20");
  de("dvdisaster ergänzt Qualitäts-Analysen");
  en("dvdisaster complements quality scans");
  ru("dvdisaster дополняет проверки качества");

subsection("index30");
  de("Vor- und  Nachteile von dvdisaster");
  en("Pro and con of dvdisaster");
  ru("dvdisaster: за и против");

# Howtos

section("howtos");
  de("Typische Anwendungen");
  en("Howtos");
  ru("Howto's");

subsection("howtos60");
  de("Das große Bild");
  en("The big picture");
  ru("The big picture");

subsubsection("howtos61");
  de("Fehlerkorrektur");
  en("error correction");
  ru("error correction");

subsubsection("howtos62");
  de("richtige Anwendung");
  en("correct usage");
  ru("correct usage");

subsubsection("howtos63");
  de("falsche Anwendung");
  en("incorrect usage");
  ru("incorrect usage");

subsection("howtos10");
  de("Datenträger auf Lesefehler prüfen");
  en("Scanning media for errors");
  ru("Поиск ошибок на носителе");

subsubsection("howtos11");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Basic settings");

subsubsection("howtos12");
  de("Prüfung durchführen");
  en("Performing the test");
  ru("foo");

subsubsection("howtos13");
  de("Ergebnisse bewerten");
  en("Interpreting the results");
  ru("foo");

subsubsection("howtos14");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos20");
  de("Fehlerkorrektur-Daten als Datei erzeugen");
  en("Putting error correction data on a separate file");
  ru("Создание данных для исправления ошибок");

subsubsection("howtos21");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Decision help");

subsubsection("howtos22");
  de("Grundeinstellungen");
  en("Basic settings for reading");
  ru("Basic settings for reading");

subsubsection("howtos23");
  de("Fehlerkorrektur-Datei erzeugen");
  en("Creating the error correction file");
  ru("Creating the error correction file");

subsubsection("howtos24");
  de("Fehlerkorrektur-Datei archivieren");
  en("Archiving error correction files");
  ru("Archiving error correction files");

subsubsection("howtos25");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos30");
  de("Fehlerkorrektur-Daten auf dem Datenträger ablegen");
  en("Putting error correction data on the medium");
  ru("Putting error correction data on the medium");

subsubsection("howtos31");
  de("Entscheidungshilfe");
  en("Decision help");
  ru("Decision help");

subsubsection("howtos32");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Basic settings");

subsubsection("howtos33");
  de("Datenträger erzeugen");
  en("Creating the medium");
  ru("Creating the medium");

subsubsection("howtos34");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos40");
  de("Datenträger-Abbild rekonstruieren");
  en("Recovering media images");
  ru("Восстановление образов носителей");

subsubsection("howtos41");
  de("Grundeinstellungen");
  en("Basic settings");
  ru("Basic settings");

subsubsection("howtos42");
  de("Abbild rekonstruieren");
  en("Recovering the image");
  ru("Recovering the image");

subsubsection("howtos43");
  de("Fortgeschrittene Einstellungen");
  en("Advanced settings");
  ru("Advanced settings");

subsection("howtos50");
  de("Informationen über Abbilder und Fehlerkorrektur-Daten anzeigen");
  en("Getting information about images and error correction data");
  ru("Получение информации об образах и данных для исправления ошибок");

subsubsection("howtos51");
  de("Informationen anzeigen");
  en("Show information");
  ru("Show information");

subsubsection("howtos52");
  de("Ausgaben für Fehlerkorrektur-Dateien");
  en("Results for error correction files");
  ru("Results for error correction files");

subsubsection("howtos53");
  de("Ausgaben für erweiterte Abbilder");
  en("Results für augmented images");
  ru("Results für augmented images");

subsubsection("howtos59");
  de("Beispiele");
  en("Examples");
  ru("Examples");

subsection("howtos90");
  de("Abbild-Kompatibilität überprüfen");
  en("Testing image compatibility");

subsubsection("howtos91");
  de("bei Fehlerkorrektur-Dateien");
  en("with error correction files");

subsubsection("howtos92");
  de("beim Ablegen von Fehlerkorrektur-Daten auf dem Datenträger");
  en("when augmenting images with error correction data");

subsection("howtosa0");
  de("Bedienelemente");
  en("Dialogs and buttons");

subsubsection("howtosa1");
  de("Laufwerk auswählen");
  en("Drive selection");

subsubsection("howtosa2");
  de("Abbild-Datei auswählen");
  en("Image file selection");

subsubsection("howtosa3");
  de("Fehlerkorrektur-Datei auswählen");
  en("Error correction file selection");

subsubsection("howtosa4");
  de("Aktionen beginnen");
  en("Starting actions");
# Download

section("download");
  de("Herunterladen");
  en("Download");
  ru("Скачать");

subsection("download10");
  de("Systemvoraussetzungen");
  en("System requirements");
  ru("Системные требования");

subsection("download20");
  de("Digitale Unterschrift");
  en("Digital signature");
  ru("Цифровая подпись");

subsection("download30");
  de("Installation");
  en("Installation");
  ru("Установка");

#subsection("download40");
#  de("Alpha-/Entwicklerversionen");
#  en("Alpha (unstable) versions");
#  ru("Альфа (нестабильные) версии");

# Questions and Answers

section("qa");
  de("Fragen und Antworten");
  en("Questions and Answers");
  ru("Вопросы и ответы");

subsection("qa10");
  de("Technische Fragen");
  en("Technical Questions");
  ru("Технические вопросы");

subsection("qa20");
  de("Fehlermeldungen");
  en("Error messages");
  ru("Сообщения об ошибках");

# Feedback

section("feedback");
  de("Fehler berichten");
  en("Bug reporting");
  ru("Сообщения об ошибках");

if(strcmp($mode, "local"))
{
  # Imprint

section("imprint");
  de("Impressum");
  en("Imprint");
  ru("Выходные данные");

   # Privacy notice

section("privacy");
  de("Datenschutzhinweis");
  en("Privacy policy");
  ru("Privacy policy");
}
?>
